==> 3.1.0.tar.gz: lib/src/node.dart <==
import 'dart:async';
import 'longlog.dart';
import 'crypto.dart';
import 'packet.dart';
import 'net_addr.dart';
import 'peer_info.dart';
import 'utils.dart';
import 'verival.dart';
import 'msg.dart';
class Send {
  final List<int> toPublicKey;
  final Msg data;
  Send(this.toPublicKey,this.data);
}
class Recv {
  final List<int> fromPublicKey;
  final Msg data;
  final List<int> id;
  Recv(this.fromPublicKey,this.data,this.id);
}
class Node {
  static Future<void> publish(
      List<int> secretKey, NetAddr longlog, String name) {
    return Verival.publish(PeerInfo(longlog, name,DateTime.now().add(Duration(days: 1))), secretKey);
  }

  static Future<PeerInfo> lookup(List<int> publicKey, Duration timeout) {
    return Verival.lookup(publicKey, timeout);
  }

  static Future<List<Recv>> receive(List<int> mySecretKey, NetAddr host,int limit,List<int> lastID,Duration timeout) async {
   var myPublicKey = Crypto.derivePK(mySecretKey);
    var last = Packet(myPublicKey, myPublicKey, [],lastID);
    var packets = await Longlog.pull(host, last, limit,timeout);
    List<Recv> list = [];
    for (var packet in packets) {
      try {
        if (!Utils.equal(packet.to, myPublicKey)) {
          continue;
        }
        var sharedKey = await Crypto.deriveKey(mySecretKey, packet.from);
        var data = await Crypto.decrypt(sharedKey, packet.data);
        list.add(Recv(packet.from, Msg.decode(data), packet.id));
      }catch(_){}
    }
    return list;
  }

  static Future<void> send(Duration timeout,List<int> fromSecretKey, Send out) async {
    var peerInfoFuture = Verival.lookup(out.toPublicKey, timeout);
    Packet packet;
    {
      var sharedKey = await Crypto.deriveKey(fromSecretKey, out.toPublicKey);
      var fromPublicKey = Crypto.derivePK(fromSecretKey);
      var cipher = await Crypto.encrypt(sharedKey, out.data.encode());
      packet = Packet(out.toPublicKey, fromPublicKey, cipher,Packet.zeroID);
    }
    var peerInfo = await peerInfoFuture;
    await Longlog.push(
        peerInfo.longlog, packet, fromSecretKey, timeout);
  }
}

==> 3.3.1.tar.gz: lib/src/node.dart <==
import 'dart:async';
import 'longlog.dart';
import 'crypto.dart';
import 'packet.dart';
import 'net_addr.dart';
import 'peer_info.dart';
import 'utils.dart';
import 'verival.dart';
import 'msg.dart';
class Send {
  final List<int> toPublicKey;
  final Msg data;
  Send(this.toPublicKey,this.data);
}
class Recv {
  final List<int> fromPublicKey;
  final Msg data;
  final List<int> id;
  Recv(this.fromPublicKey,this.data,this.id);
}
class Node {
  static Future<void> publish(
      List<int> secretKey, NetAddr longlog, String name,Duration ttl) {
    return Verival.publish(PeerInfo(longlog, name,DateTime.now().add(ttl)), secretKey);
  }

  static Future<PeerInfo> lookup(List<int> publicKey, Duration timeout) {
    return Verival.lookup(publicKey, timeout);
  }

  static Future<List<Recv>> receive(List<int> mySecretKey, NetAddr host,int limit,List<int> lastID,Duration timeout) async {
   var myPublicKey = Crypto.derivePK(mySecretKey);
    var last = Packet(myPublicKey, myPublicKey, [],lastID);
    var packets = await Longlog.pull(host, last.encode().sublist(0,1+Packet.pkSize+8), limit,timeout);
    List<Recv> list = [];
    for (var packet in packets) {
      try {
        if (!Utils.equal(packet.to, myPublicKey)) {
          continue;
        }
        var sharedKey = await Crypto.deriveKey(mySecretKey, packet.from);
        var data = await Crypto.decrypt(sharedKey, packet.data);
        list.add(Recv(packet.from, Msg.decode(data), packet.id));
      }catch(_){}
    }
    return list;
  }

  static Future<void> send(Duration timeout,List<int> fromSecretKey, Send out) async {
    var peerInfoFuture = Verival.lookup(out.toPublicKey, timeout);
    Packet packet;
    {
      var sharedKey = await Crypto.deriveKey(fromSecretKey, out.toPublicKey);
      var fromPublicKey = Crypto.derivePK(fromSecretKey);
      var cipher = await Crypto.encrypt(sharedKey, out.data.encode());
      packet = Packet(out.toPublicKey, fromPublicKey, cipher,Packet.zeroID);
    }
    var peerInfo = await peerInfoFuture;
    await Longlog.push(
        peerInfo.longlog, packet.encode(), fromSecretKey, timeout);
  }
}
